@@ -12,17 +12,14 @@ from classifier.data_loader import get_feature_from_data
 from utility.loss import *
 
 
-class BertMtClassifier(nn.Module):
+class MtClassifier(nn.Module):
 
-    def __init__(self, tasks_detail, model_config, maxlen=512, dropout=0.1):
+    def __init__(self, tasks_detail, tokenizer, pretrained, maxlen=512, dropout=0.1):
         super().__init__()
         self.device = 'cuda' if torch.cuda.is_available() else 'cpu'
         print('Using device:', self.device)
-        if 'albert_chinese' in model_config:
-            self.tokenizer = BertTokenizer.from_pretrained(model_config)
-        else:
-            self.tokenizer = AutoTokenizer.from_pretrained(model_config)
-        self.pretrained = AutoModel.from_pretrained(model_config)
+        self.tokenizer = tokenizer
+        self.pretrained = pretrained
 
         self.dropout = nn.Dropout(dropout)
         self.loss_fct = FocalLoss()
@@ -45,9 +42,9 @@ class BertMtClassifier(nn.Module):
 
     def forward(self, batch_data, eval=False):
         tasks = batch_data['task']
-        inputs = torch.tensor(batch_data['input']).to(self.device)
-        targets = torch.tensor(batch_data['target']).to(self.device)
-        masks = torch.tensor(batch_data['mask']).to(self.device)
+        inputs = torch.as_tensor(batch_data['input']).to(self.device)
+        targets = torch.as_tensor(batch_data['target']).to(self.device)
+        masks = torch.as_tensor(batch_data['mask']).to(self.device)
 
         result_dict = {
             'label_prob_all': [],
@@ -73,7 +70,7 @@ class BertMtClassifier(nn.Module):
                 if 'multi_target' in task:
                     reshaped_logits = sigmoid(reshaped_logits)
                 else:
-                    reshaped_logits = softmax(reshaped_logits)
+                    reshaped_logits = softmax(reshaped_logits,dim=1)
                 logit_prob = reshaped_logits[0].data.tolist()
                 logit_label = dict(zip(task_lables, logit_prob))
                 result_dict['label_prob_all'].append({task: logit_label})
@@ -104,6 +101,6 @@ class BertMtClassifier(nn.Module):
                     return [i[task] for i in result['label_map'] if task in i], result
                 else:
                     task_map = [i[task] for i in result['label_prob_all'] if task in i][0]
-                    return sorted(task_map, key=task_map.get,reverse=True)[:topk], result
+                    return sorted(task_map, key=task_map.get, reverse=True)[:topk], result
             else:
                 return [""], {}
