@@ -8,7 +8,6 @@ sys.path.append(os.path.abspath(os.path.join(dir_path, os.pardir)))
 
 import torch
 import torch.nn as nn
-from transformers import *
 from gen_onebyone.data_loader import get_feature_from_data
 from itertools import combinations
 from torch.nn.functional import softmax
@@ -16,17 +15,18 @@ from math import log
 from utility.loss import *
 from utility.tok import *
 import numpy as np
-import random
 
 
 class OneByOne(nn.Module):
-    def __init__(self, tokenizer, pretrained, maxlen=512):
+    def __init__(self, tokenizer, pretrained, maxlen=512, lossdrop=False):
         super().__init__()
         self.tokenizer = tokenizer
         self.pretrained = pretrained
         self.model = nn.Linear(self.pretrained.config.hidden_size, self.tokenizer.__len__())
         self.device = 'cuda' if torch.cuda.is_available() else 'cpu'
         self.maxlen = maxlen
+        self.lossdrop = lossdrop
+        self.dropper = LossDropper()
         print('Using device:', self.device)
         self.model.to(self.device)
 
@@ -59,15 +59,22 @@ class OneByOne(nn.Module):
         else:
             loss_tensors = torch.as_tensor(targets).to(self.device)
             negativeloss_tensors = torch.as_tensor(negative_targets).to(self.device)
-            loss_fct = nn.CrossEntropyLoss(ignore_index=-1)  # -1 index = padding token
+            loss_fct = nn.CrossEntropyLoss(reduction='none', ignore_index=-1)  # -1 index = padding token
             masked_lm_loss = loss_fct(prediction_scores.view(-1, self.pretrained.config.vocab_size),
                                       loss_tensors.view(-1))
 
-            negative_loss_fct = NegativeCElLoss().to(self.device)
+            negative_loss_fct = NegativeCElLoss(reduction='none', ignore_index=-1).to(self.device)
             negative_loss = negative_loss_fct(prediction_scores.view(-1, self.pretrained.config.vocab_size),
                                               negativeloss_tensors.view(-1))
 
             masked_lm_loss += negative_loss
+            masked_lm_loss = masked_lm_loss.view(-1, len(targets))  # view by batch size
+            masked_lm_loss = masked_lm_loss.mean(dim=0)
+            if self.lossdrop:
+                mask = self.dropper(masked_lm_loss)
+                masked_lm_loss *= mask
+            masked_lm_loss = masked_lm_loss.mean()
+
             outputs = masked_lm_loss
         return outputs
 
