@@ -14,17 +14,14 @@ from utility.loss import *
 from tag.data_loader import get_feature_from_data
 
 
-class BertTagger(nn.Module):
+class Tagger(nn.Module):
 
-    def __init__(self, labels, model_config, maxlen=512, dropout=0.2):
+    def __init__(self, labels, tokenizer, pretrained, maxlen=512, dropout=0.2):
         super().__init__()
         self.device = 'cuda' if torch.cuda.is_available() else 'cpu'
         print('Using device:', self.device)
-        if 'albert_chinese' in model_config:
-            self.tokenizer = BertTokenizer.from_pretrained(model_config)
-        else:
-            self.tokenizer = AutoTokenizer.from_pretrained(model_config)
-        self.pretrained = AutoModel.from_pretrained(model_config)
+        self.tokenizer = tokenizer
+        self.pretrained = pretrained
         self.dropout = nn.Dropout(dropout)
         self.tagger = nn.Linear(self.pretrained.config.hidden_size, len(labels))
         self.labels = labels
@@ -41,8 +38,8 @@ class BertTagger(nn.Module):
         masks = batch_data["mask"]
 
         # bert embedding
-        token_tensor = torch.tensor(inputs, dtype=torch.long).to(self.device)
-        mask_tensors = torch.tensor(masks).to(self.device)
+        token_tensor = torch.as_tensor(inputs, dtype=torch.long).to(self.device)
+        mask_tensors = torch.as_tensor(masks).to(self.device)
         bert_output = self.pretrained(token_tensor, attention_mask=mask_tensors)
         res = bert_output[0]
         pooled_output = self.dropout(res)
@@ -54,7 +51,7 @@ class BertTagger(nn.Module):
                 'label_map': []
             }
 
-            ilogit = softmax(reshaped_logits[0])
+            ilogit = softmax(reshaped_logits[0], dim=1)
             result_labels = ilogit.data.tolist()
             result_items = []
             for pos_logit_prob in result_labels:
@@ -71,7 +68,7 @@ class BertTagger(nn.Module):
             outputs = result_dict
         else:
             targets = batch_data["target"]
-            target_tensor = torch.tensor(targets, dtype=torch.long).to(self.device)
+            target_tensor = torch.as_tensor(targets, dtype=torch.long).to(self.device)
             loss = self.loss_fct(reshaped_logits.view(-1, len(self.labels)), target_tensor.view(-1))
             outputs = loss
 
